@@ -41,23 +41,23 @@ test_that("isStationary gives correct answer", {
 })
 
 test_that("isIdentifiable gives correct answer", {
-  expect_true(isIdentifiable(1, 1, params11, StMAR=TRUE))
-  expect_true(isIdentifiable(1, 1, params11, restricted=TRUE, StMAR=TRUE))
+  expect_true(isIdentifiable(1, 1, params11, model="StMAR"))
+  expect_true(isIdentifiable(1, 1, params11, model="StMAR", restricted=TRUE))
   expect_true(isIdentifiable(1, 2, params12))
-  expect_false(isIdentifiable(1, 2, params12_2, StMAR=TRUE))
+  expect_false(isIdentifiable(1, 2, params12_2, model="StMAR"))
   expect_false(isIdentifiable(2, 2, params22))
   expect_false(isIdentifiable(1, 3, params13))
-  expect_false(isIdentifiable(2, 3, params23, StMAR=TRUE))
-  expect_true(isIdentifiable(1, 2, params12r, restricted=TRUE, StMAR=TRUE))
+  expect_false(isIdentifiable(2, 3, params23, model="StMAR"))
+  expect_true(isIdentifiable(1, 2, params12r, model="StMAR", restricted=TRUE))
   expect_true(isIdentifiable(2, 2, params22r, restricted=TRUE))
-  expect_false(isIdentifiable(2, 3, params23r, restricted=TRUE, StMAR=TRUE))
+  expect_false(isIdentifiable(2, 3, params23r, model="StMAR", restricted=TRUE))
   expect_false(isIdentifiable(1, 3, params13r, restricted=TRUE))
   expect_true(isIdentifiable(2, 3, params23r2, restricted=TRUE))
-  expect_false(isIdentifiable(1, c(2,2), params14gs, GStMAR=TRUE))
-  expect_true(isIdentifiable(2, c(1,2), params23gs, GStMAR=TRUE))
-  expect_true(isIdentifiable(1, c(1,1), params12gs, GStMAR=TRUE))
-  expect_true(isIdentifiable(2, c(1,1), params22gsr, GStMAR=TRUE, restricted=TRUE))
-  expect_true(isIdentifiable(1, c(2,1), params13gsr, GStMAR=TRUE, restricted=TRUE))
-  expect_false(isIdentifiable(1, c(2,2), params14gsr, GStMAR=TRUE, restricted=TRUE))
+  expect_false(isIdentifiable(1, c(2,2), params14gs, model="G-StMAR"))
+  expect_true(isIdentifiable(2, c(1,2), params23gs, model="G-StMAR"))
+  expect_true(isIdentifiable(1, c(1,1), params12gs, model="G-StMAR"))
+  expect_true(isIdentifiable(2, c(1,1), params22gsr, model="G-StMAR", restricted=TRUE))
+  expect_true(isIdentifiable(1, c(2,1), params13gsr, model="G-StMAR", restricted=TRUE))
+  expect_false(isIdentifiable(1, c(2,2), params14gsr, model="G-StMAR", restricted=TRUE))
 })
 
