@@ -18,7 +18,9 @@ gmar23r <- GSMAR(data=VIX, p=2, M=3, params=params23r, model="GMAR", restricted=
 stmar22c <- GSMAR(data=VIX, p=2, M=2, params=params22c, model="StMAR", constraints=list(R4, R3))
 gmar32cr <- GSMAR(data=VIX, p=3, M=2, params=params32cr, model="GMAR", restricted=TRUE, constraints=R1)
 
-set.seed(1); pred12 <- predict.gsmar(gmar12, n_ahead=1, nsimu=50, plotRes=FALSE, pred_type="mean")
+set.seed(1); pred12_0 <- predict.gsmar(gmar12, n_ahead=1, nsimu=1, pi_type="none", plotRes=FALSE, pred_type="mean")
+set.seed(1); pred12 <- predict.gsmar(gmar12, n_ahead=1, nsimu=50, pi=c(0.90, 0.80), plotRes=FALSE, pred_type="mean")
+set.seed(2); pred23_0 <- predict.gsmar(gmar23, n_ahead=1, nsimu=1, plotRes=FALSE, pred_type="cond_mean")
 set.seed(2); pred23 <- predict.gsmar(gmar23, n_ahead=3, nsimu=50, pi=c(0.99, 0.90, 0.60), plotRes=FALSE, pred_type="median")
 set.seed(3); pred12r <- predict.gsmar(gmar12r, n_ahead=3, nsimu=50, pi=c(0.999, 0.001), plotRes=FALSE, pred_type="median")
 set.seed(4); pred23r <- predict.gsmar(gmar23r, n_ahead=1, nsimu=50, pi=c(0.5), plotRes=FALSE, pred_type="mean")
@@ -26,7 +28,9 @@ set.seed(5); pred22c <- predict.gsmar(stmar22c, n_ahead=1, nsimu=20, pi=c(0.99,
 set.seed(6); pred32cr <- predict.gsmar(gmar32cr, n_ahead=1, nsimu=10, pi=c(0.90), plotRes=FALSE, pred_type="mean")
 
 test_that("predict.gsmar gives correct prediction", {
+  expect_equal(pred12_0$pred, 10.93488, tolerance=1e-3)
   expect_equal(pred12$pred, 11.15113, tolerance=1e-3)
+  expect_equal(pred23_0$pred, 11.04499, tolerance=1e-3)
   expect_equal(pred23$pred[3], 10.77946, tolerance=1e-3)
   expect_equal(pred12r$pred[2], 11.94374, tolerance=1e-3)
   expect_equal(pred23r$pred, 10.41577, tolerance=1e-3)
@@ -35,7 +39,7 @@ test_that("predict.gsmar gives correct prediction", {
 })
 
 test_that("predict.gsmar gives correct prediction intervals", {
-  expect_equal(pred12$pred_ints[1], 10.1512, tolerance=1e-3)
+  expect_equal(pred12$pred_ints[1], 10.37893, tolerance=1e-3)
   expect_equal(pred12$pred_ints[3], 11.69211, tolerance=1e-3)
   expect_equal(pred23$pred_ints[3], 9.144938, tolerance=1e-3)
   expect_equal(pred23$pred_ints[11], 11.56006, tolerance=1e-3)
