@@ -21,7 +21,7 @@ test_that("simulateGSMAR simulates correctly from non-restricted process", {
   expect_equal(data23$mixing_weights[,2], 0.2067762, tolerance=1e-6)
   expect_equal(data23init$sample[2], 1.351309, tolerance=1e-6)
   expect_equal(data13gs$sample[1], -0.3833485, tolerance=1e-6)
-  expect_equal(data13gs$mixing_weights[3,3], 0.00969763, tolerance=1e-6)
+  expect_equal(data13gs$mixing_weights[3, 3], 0.00969763, tolerance=1e-6)
 })
 
 params12r <- c(1, 2, -0.9, 1, 2, 0.7)
@@ -41,10 +41,10 @@ test_that("simulateGSMAR simulates correctly from restricted process", {
   expect_equal(data12r$component, 2)
   expect_equal(data12r$mixing_weights[,1],  0.7716839, tolerance=1e-6)
   expect_equal(data12rinit$sample[1], 0.6312408, tolerance=1e-6)
-  expect_equal(data23r$sample[2], -0.5006049, tolerance=1e-6)
-  expect_equal(data23r$component[2], 2)
-  expect_equal(data22gsr$sample[2], 2.583507, tolerance=1e-6)
-  expect_equal(data22gsr$component[1], 2)
+  expect_equal(data23r$sample[2], 0.004890296, tolerance=1e-6)
+  expect_equal(data23r$component[2], 1)
+  expect_equal(data22gsr$sample[2], 2.160116, tolerance=1e-6)
+  expect_equal(data22gsr$component[1], 1)
 })
 
 R1 <- matrix(c(1, 0, 0, 0, 0, 1), ncol=2)
@@ -62,11 +62,11 @@ set.seed(3); data22gsrc <- simulateGSMAR(gstmar22cr, nsimu=2)
 
 
 test_that("simulateGSMAR simulates correctly from constrained process", {
-  expect_equal(data22c$sample,  0.1681538, tolerance=1e-6)
-  expect_equal(data22c$mixing_weights[,1], 0.8956446, tolerance=1e-6)
+  expect_equal(data22c$sample, 1.240905, tolerance=1e-6)
+  expect_equal(data22c$mixing_weights[,1], 0.9172016, tolerance=1e-6)
   expect_equal(data32cr$sample[2], 0.7406432, tolerance=1e-6)
   expect_equal(data32cr$component[2], 1)
-  expect_equal(data22gsrc$sample[2], -1.732949, tolerance=1e-6)
+  expect_equal(data22gsrc$sample[2], -0.4407819, tolerance=1e-6)
   expect_equal(data22gsrc$component[1], 2)
-  expect_equal(data22gsrc$mixing_weights[,1], c(0.3122889, 0.3084366), tolerance=1e-6)
+  expect_equal(data22gsrc$mixing_weights[,1], c(0.3099519, 0.3092720), tolerance=1e-6)
 })
